.. currentmodule:: pvlib

Bifacial
========

Functions for calculating front and back surface irradiance

.. autosummary::
   :toctree: generated/

   bifacial.pvfactors.pvfactors_timeseries
   bifacial.infinite_sheds.get_irradiance
   bifacial.infinite_sheds.get_irradiance_poa
